# SPDX-FileCopyrightText: 2023 Civic Hacker, LLC
#
# SPDX-License-Identifier: GPL-3.0-or-later

FEMALE_KLINGON = [
    "Azetbur",
    "B'Etor",
    "Ba'el",
    "Ch'Rega",
    "Ezri",
    "Grilka",
    "Jadzia Dax",
    "K'Ehleyr",
    "Lursa",
    "Miral",
    "Valkris",
]

MALE_KLINGON = [
    "Antaak",
    "Atul",
    "Brota",
    "Klaang",
    "Kol",
    "Kol-Sha",
    "Magh",
    "Maltz",
    "Orak",
    "Rodek",
    "Sisko",
    "Toral",
    "Voq",
]
